# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'SubscriptionBillingAddressArgs',
    'SubscriptionPaymentGatewayArgs',
    'SubscriptionPaymentGatewayMerchantDefinedDataArgs',
    'SubscriptionPaymentOptionArgs',
    'SubscriptionSubscriptionArgs',
    'SubscriptionSubscriptionBillingAddressArgs',
    'SubscriptionSubscriptionPaymentGatewayArgs',
    'SubscriptionSubscriptionPaymentGatewayMerchantDefinedDataArgs',
    'SubscriptionSubscriptionPaymentOptionArgs',
    'SubscriptionSubscriptionTaxInfoArgs',
    'SubscriptionTaxInfoArgs',
    'GetInvoicesFilterArgs',
    'GetInvoicesInvoiceLinesFilterArgs',
    'GetSubscriptionsFilterArgs',
]

@pulumi.input_type
class SubscriptionBillingAddressArgs:
    def __init__(__self__, *,
                 address_key: Optional[pulumi.Input[str]] = None,
                 city: Optional[pulumi.Input[str]] = None,
                 company_name: Optional[pulumi.Input[str]] = None,
                 country: Optional[pulumi.Input[str]] = None,
                 email_address: Optional[pulumi.Input[str]] = None,
                 first_name: Optional[pulumi.Input[str]] = None,
                 last_name: Optional[pulumi.Input[str]] = None,
                 line1: Optional[pulumi.Input[str]] = None,
                 line2: Optional[pulumi.Input[str]] = None,
                 postal_code: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] address_key: (Updatable) Address identifier.
        :param pulumi.Input[str] city: (Updatable) Name of the city.
        :param pulumi.Input[str] company_name: (Updatable) Name of the customer company.
        :param pulumi.Input[str] country: (Updatable) Country of the address.
        :param pulumi.Input[str] email_address: (Updatable) The email address of the paypal user.
        :param pulumi.Input[str] first_name: (Updatable) First name of the paypal user.
        :param pulumi.Input[str] last_name: (Updatable) Last name of the paypal user.
        :param pulumi.Input[str] line1: (Updatable) Address line 1.
        :param pulumi.Input[str] line2: (Updatable) Address line 2.
        :param pulumi.Input[str] postal_code: (Updatable) Post code of the address.
        :param pulumi.Input[str] state: (Updatable) State of the address.
        """
        if address_key is not None:
            pulumi.set(__self__, "address_key", address_key)
        if city is not None:
            pulumi.set(__self__, "city", city)
        if company_name is not None:
            pulumi.set(__self__, "company_name", company_name)
        if country is not None:
            pulumi.set(__self__, "country", country)
        if email_address is not None:
            pulumi.set(__self__, "email_address", email_address)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)
        if line1 is not None:
            pulumi.set(__self__, "line1", line1)
        if line2 is not None:
            pulumi.set(__self__, "line2", line2)
        if postal_code is not None:
            pulumi.set(__self__, "postal_code", postal_code)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="addressKey")
    def address_key(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Address identifier.
        """
        return pulumi.get(self, "address_key")

    @address_key.setter
    def address_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "address_key", value)

    @property
    @pulumi.getter
    def city(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Name of the city.
        """
        return pulumi.get(self, "city")

    @city.setter
    def city(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "city", value)

    @property
    @pulumi.getter(name="companyName")
    def company_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Name of the customer company.
        """
        return pulumi.get(self, "company_name")

    @company_name.setter
    def company_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "company_name", value)

    @property
    @pulumi.getter
    def country(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Country of the address.
        """
        return pulumi.get(self, "country")

    @country.setter
    def country(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "country", value)

    @property
    @pulumi.getter(name="emailAddress")
    def email_address(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The email address of the paypal user.
        """
        return pulumi.get(self, "email_address")

    @email_address.setter
    def email_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email_address", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) First name of the paypal user.
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Last name of the paypal user.
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_name", value)

    @property
    @pulumi.getter
    def line1(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Address line 1.
        """
        return pulumi.get(self, "line1")

    @line1.setter
    def line1(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "line1", value)

    @property
    @pulumi.getter
    def line2(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Address line 2.
        """
        return pulumi.get(self, "line2")

    @line2.setter
    def line2(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "line2", value)

    @property
    @pulumi.getter(name="postalCode")
    def postal_code(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Post code of the address.
        """
        return pulumi.get(self, "postal_code")

    @postal_code.setter
    def postal_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "postal_code", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) State of the address.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


@pulumi.input_type
class SubscriptionPaymentGatewayArgs:
    def __init__(__self__, *,
                 merchant_defined_datas: Optional[pulumi.Input[Sequence[pulumi.Input['SubscriptionPaymentGatewayMerchantDefinedDataArgs']]]] = None):
        """
        :param pulumi.Input[Sequence[pulumi.Input['SubscriptionPaymentGatewayMerchantDefinedDataArgs']]] merchant_defined_datas: (Updatable) Merchant details.
        """
        if merchant_defined_datas is not None:
            pulumi.set(__self__, "merchant_defined_datas", merchant_defined_datas)

    @property
    @pulumi.getter(name="merchantDefinedDatas")
    def merchant_defined_datas(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SubscriptionPaymentGatewayMerchantDefinedDataArgs']]]]:
        """
        (Updatable) Merchant details.
        """
        return pulumi.get(self, "merchant_defined_datas")

    @merchant_defined_datas.setter
    def merchant_defined_datas(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SubscriptionPaymentGatewayMerchantDefinedDataArgs']]]]):
        pulumi.set(self, "merchant_defined_datas", value)


@pulumi.input_type
class SubscriptionPaymentGatewayMerchantDefinedDataArgs:
    def __init__(__self__, *,
                 cloud_account_name: Optional[pulumi.Input[str]] = None,
                 promo_type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] cloud_account_name: (Updatable) Cloud account name.
        :param pulumi.Input[str] promo_type: (Updatable) Promotion type code.
        """
        if cloud_account_name is not None:
            pulumi.set(__self__, "cloud_account_name", cloud_account_name)
        if promo_type is not None:
            pulumi.set(__self__, "promo_type", promo_type)

    @property
    @pulumi.getter(name="cloudAccountName")
    def cloud_account_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Cloud account name.
        """
        return pulumi.get(self, "cloud_account_name")

    @cloud_account_name.setter
    def cloud_account_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloud_account_name", value)

    @property
    @pulumi.getter(name="promoType")
    def promo_type(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Promotion type code.
        """
        return pulumi.get(self, "promo_type")

    @promo_type.setter
    def promo_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "promo_type", value)


@pulumi.input_type
class SubscriptionPaymentOptionArgs:
    def __init__(__self__, *,
                 credit_card_type: Optional[pulumi.Input[str]] = None,
                 email_address: Optional[pulumi.Input[str]] = None,
                 ext_billing_agreement_id: Optional[pulumi.Input[str]] = None,
                 first_name: Optional[pulumi.Input[str]] = None,
                 last_digits: Optional[pulumi.Input[str]] = None,
                 last_name: Optional[pulumi.Input[str]] = None,
                 name_on_card: Optional[pulumi.Input[str]] = None,
                 payment_method: Optional[pulumi.Input[str]] = None,
                 time_expiration: Optional[pulumi.Input[str]] = None,
                 wallet_instrument_id: Optional[pulumi.Input[str]] = None,
                 wallet_transaction_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] credit_card_type: (Updatable) Credit card type.
        :param pulumi.Input[str] email_address: (Updatable) The email address of the paypal user.
        :param pulumi.Input[str] ext_billing_agreement_id: (Updatable) Agreement id for the paypal account.
        :param pulumi.Input[str] first_name: (Updatable) First name of the paypal user.
        :param pulumi.Input[str] last_digits: (Updatable) Last four digits of the card.
        :param pulumi.Input[str] last_name: (Updatable) Last name of the paypal user.
        :param pulumi.Input[str] name_on_card: (Updatable) Name on the credit card.
        :param pulumi.Input[str] payment_method: (Updatable) Payment method
        :param pulumi.Input[str] time_expiration: (Updatable) Expired date of the credit card.
        :param pulumi.Input[str] wallet_instrument_id: (Updatable) Wallet instrument internal id.
        :param pulumi.Input[str] wallet_transaction_id: (Updatable) Wallet transaction id.
        """
        if credit_card_type is not None:
            pulumi.set(__self__, "credit_card_type", credit_card_type)
        if email_address is not None:
            pulumi.set(__self__, "email_address", email_address)
        if ext_billing_agreement_id is not None:
            pulumi.set(__self__, "ext_billing_agreement_id", ext_billing_agreement_id)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if last_digits is not None:
            pulumi.set(__self__, "last_digits", last_digits)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)
        if name_on_card is not None:
            pulumi.set(__self__, "name_on_card", name_on_card)
        if payment_method is not None:
            pulumi.set(__self__, "payment_method", payment_method)
        if time_expiration is not None:
            pulumi.set(__self__, "time_expiration", time_expiration)
        if wallet_instrument_id is not None:
            pulumi.set(__self__, "wallet_instrument_id", wallet_instrument_id)
        if wallet_transaction_id is not None:
            pulumi.set(__self__, "wallet_transaction_id", wallet_transaction_id)

    @property
    @pulumi.getter(name="creditCardType")
    def credit_card_type(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Credit card type.
        """
        return pulumi.get(self, "credit_card_type")

    @credit_card_type.setter
    def credit_card_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "credit_card_type", value)

    @property
    @pulumi.getter(name="emailAddress")
    def email_address(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The email address of the paypal user.
        """
        return pulumi.get(self, "email_address")

    @email_address.setter
    def email_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email_address", value)

    @property
    @pulumi.getter(name="extBillingAgreementId")
    def ext_billing_agreement_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Agreement id for the paypal account.
        """
        return pulumi.get(self, "ext_billing_agreement_id")

    @ext_billing_agreement_id.setter
    def ext_billing_agreement_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ext_billing_agreement_id", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) First name of the paypal user.
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="lastDigits")
    def last_digits(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Last four digits of the card.
        """
        return pulumi.get(self, "last_digits")

    @last_digits.setter
    def last_digits(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_digits", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Last name of the paypal user.
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_name", value)

    @property
    @pulumi.getter(name="nameOnCard")
    def name_on_card(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Name on the credit card.
        """
        return pulumi.get(self, "name_on_card")

    @name_on_card.setter
    def name_on_card(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_on_card", value)

    @property
    @pulumi.getter(name="paymentMethod")
    def payment_method(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Payment method
        """
        return pulumi.get(self, "payment_method")

    @payment_method.setter
    def payment_method(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_method", value)

    @property
    @pulumi.getter(name="timeExpiration")
    def time_expiration(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Expired date of the credit card.
        """
        return pulumi.get(self, "time_expiration")

    @time_expiration.setter
    def time_expiration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_expiration", value)

    @property
    @pulumi.getter(name="walletInstrumentId")
    def wallet_instrument_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Wallet instrument internal id.
        """
        return pulumi.get(self, "wallet_instrument_id")

    @wallet_instrument_id.setter
    def wallet_instrument_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "wallet_instrument_id", value)

    @property
    @pulumi.getter(name="walletTransactionId")
    def wallet_transaction_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Wallet transaction id.
        """
        return pulumi.get(self, "wallet_transaction_id")

    @wallet_transaction_id.setter
    def wallet_transaction_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "wallet_transaction_id", value)


@pulumi.input_type
class SubscriptionSubscriptionArgs:
    def __init__(__self__, *,
                 subscription_plan_number: pulumi.Input[str],
                 bill_to_cust_account_id: Optional[pulumi.Input[str]] = None,
                 billing_addresses: Optional[pulumi.Input[Sequence[pulumi.Input['SubscriptionSubscriptionBillingAddressArgs']]]] = None,
                 currency_code: Optional[pulumi.Input[str]] = None,
                 gsi_org_code: Optional[pulumi.Input[str]] = None,
                 id: Optional[pulumi.Input[str]] = None,
                 is_intent_to_pay: Optional[pulumi.Input[bool]] = None,
                 language_code: Optional[pulumi.Input[str]] = None,
                 organization_id: Optional[pulumi.Input[str]] = None,
                 payment_gateway: Optional[pulumi.Input['SubscriptionSubscriptionPaymentGatewayArgs']] = None,
                 payment_options: Optional[pulumi.Input[Sequence[pulumi.Input['SubscriptionSubscriptionPaymentOptionArgs']]]] = None,
                 plan_type: Optional[pulumi.Input[str]] = None,
                 ship_to_cust_acct_role_id: Optional[pulumi.Input[str]] = None,
                 ship_to_cust_acct_site_id: Optional[pulumi.Input[str]] = None,
                 tax_info: Optional[pulumi.Input['SubscriptionSubscriptionTaxInfoArgs']] = None,
                 time_plan_upgrade: Optional[pulumi.Input[str]] = None,
                 time_start: Optional[pulumi.Input[str]] = None,
                 upgrade_state: Optional[pulumi.Input[str]] = None,
                 upgrade_state_details: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] subscription_plan_number: (Updatable) Subscription plan number.
        :param pulumi.Input[str] bill_to_cust_account_id: (Updatable) Bill to customer Account id.
        :param pulumi.Input[Sequence[pulumi.Input['SubscriptionSubscriptionBillingAddressArgs']]] billing_addresses: (Updatable) Billing address details model.
        :param pulumi.Input[str] currency_code: (Updatable) Currency code
        :param pulumi.Input[str] gsi_org_code: (Updatable) GSI Subscription external code.
        :param pulumi.Input[str] id: (Updatable) Subscription id identifier (OCID).
        :param pulumi.Input[bool] is_intent_to_pay: (Updatable) Payment intension.
        :param pulumi.Input[str] language_code: (Updatable) Language short code (en, de, hu, etc)
        :param pulumi.Input[str] organization_id: (Updatable) GSI organization external identifier.
        :param pulumi.Input['SubscriptionSubscriptionPaymentGatewayArgs'] payment_gateway: (Updatable) Payment gateway details.
        :param pulumi.Input[Sequence[pulumi.Input['SubscriptionSubscriptionPaymentOptionArgs']]] payment_options: (Updatable) Payment option list of a subscription.
        :param pulumi.Input[str] plan_type: (Updatable) Subscription plan type.
        :param pulumi.Input[str] ship_to_cust_acct_role_id: (Updatable) Ship to customer account role.
        :param pulumi.Input[str] ship_to_cust_acct_site_id: (Updatable) Ship to customer account site address id.
        :param pulumi.Input['SubscriptionSubscriptionTaxInfoArgs'] tax_info: (Updatable) Tax details.
        :param pulumi.Input[str] time_plan_upgrade: (Updatable) Date of upgrade/conversion when planType changed from FREE_TIER to PAYG
        :param pulumi.Input[str] time_start: (Updatable) Start date of the subscription.
        :param pulumi.Input[str] upgrade_state: (Updatable) Status of the upgrade.
        :param pulumi.Input[str] upgrade_state_details: (Updatable) This field is used to describe the Upgrade State in case of error (E.g. Upgrade failure caused by interfacing Tax details- TaxError)
        """
        pulumi.set(__self__, "subscription_plan_number", subscription_plan_number)
        if bill_to_cust_account_id is not None:
            pulumi.set(__self__, "bill_to_cust_account_id", bill_to_cust_account_id)
        if billing_addresses is not None:
            pulumi.set(__self__, "billing_addresses", billing_addresses)
        if currency_code is not None:
            pulumi.set(__self__, "currency_code", currency_code)
        if gsi_org_code is not None:
            pulumi.set(__self__, "gsi_org_code", gsi_org_code)
        if id is not None:
            pulumi.set(__self__, "id", id)
        if is_intent_to_pay is not None:
            pulumi.set(__self__, "is_intent_to_pay", is_intent_to_pay)
        if language_code is not None:
            pulumi.set(__self__, "language_code", language_code)
        if organization_id is not None:
            pulumi.set(__self__, "organization_id", organization_id)
        if payment_gateway is not None:
            pulumi.set(__self__, "payment_gateway", payment_gateway)
        if payment_options is not None:
            pulumi.set(__self__, "payment_options", payment_options)
        if plan_type is not None:
            pulumi.set(__self__, "plan_type", plan_type)
        if ship_to_cust_acct_role_id is not None:
            pulumi.set(__self__, "ship_to_cust_acct_role_id", ship_to_cust_acct_role_id)
        if ship_to_cust_acct_site_id is not None:
            pulumi.set(__self__, "ship_to_cust_acct_site_id", ship_to_cust_acct_site_id)
        if tax_info is not None:
            pulumi.set(__self__, "tax_info", tax_info)
        if time_plan_upgrade is not None:
            pulumi.set(__self__, "time_plan_upgrade", time_plan_upgrade)
        if time_start is not None:
            pulumi.set(__self__, "time_start", time_start)
        if upgrade_state is not None:
            pulumi.set(__self__, "upgrade_state", upgrade_state)
        if upgrade_state_details is not None:
            pulumi.set(__self__, "upgrade_state_details", upgrade_state_details)

    @property
    @pulumi.getter(name="subscriptionPlanNumber")
    def subscription_plan_number(self) -> pulumi.Input[str]:
        """
        (Updatable) Subscription plan number.
        """
        return pulumi.get(self, "subscription_plan_number")

    @subscription_plan_number.setter
    def subscription_plan_number(self, value: pulumi.Input[str]):
        pulumi.set(self, "subscription_plan_number", value)

    @property
    @pulumi.getter(name="billToCustAccountId")
    def bill_to_cust_account_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Bill to customer Account id.
        """
        return pulumi.get(self, "bill_to_cust_account_id")

    @bill_to_cust_account_id.setter
    def bill_to_cust_account_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bill_to_cust_account_id", value)

    @property
    @pulumi.getter(name="billingAddresses")
    def billing_addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SubscriptionSubscriptionBillingAddressArgs']]]]:
        """
        (Updatable) Billing address details model.
        """
        return pulumi.get(self, "billing_addresses")

    @billing_addresses.setter
    def billing_addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SubscriptionSubscriptionBillingAddressArgs']]]]):
        pulumi.set(self, "billing_addresses", value)

    @property
    @pulumi.getter(name="currencyCode")
    def currency_code(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Currency code
        """
        return pulumi.get(self, "currency_code")

    @currency_code.setter
    def currency_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "currency_code", value)

    @property
    @pulumi.getter(name="gsiOrgCode")
    def gsi_org_code(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) GSI Subscription external code.
        """
        return pulumi.get(self, "gsi_org_code")

    @gsi_org_code.setter
    def gsi_org_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "gsi_org_code", value)

    @property
    @pulumi.getter
    def id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Subscription id identifier (OCID).
        """
        return pulumi.get(self, "id")

    @id.setter
    def id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "id", value)

    @property
    @pulumi.getter(name="isIntentToPay")
    def is_intent_to_pay(self) -> Optional[pulumi.Input[bool]]:
        """
        (Updatable) Payment intension.
        """
        return pulumi.get(self, "is_intent_to_pay")

    @is_intent_to_pay.setter
    def is_intent_to_pay(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "is_intent_to_pay", value)

    @property
    @pulumi.getter(name="languageCode")
    def language_code(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Language short code (en, de, hu, etc)
        """
        return pulumi.get(self, "language_code")

    @language_code.setter
    def language_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "language_code", value)

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) GSI organization external identifier.
        """
        return pulumi.get(self, "organization_id")

    @organization_id.setter
    def organization_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "organization_id", value)

    @property
    @pulumi.getter(name="paymentGateway")
    def payment_gateway(self) -> Optional[pulumi.Input['SubscriptionSubscriptionPaymentGatewayArgs']]:
        """
        (Updatable) Payment gateway details.
        """
        return pulumi.get(self, "payment_gateway")

    @payment_gateway.setter
    def payment_gateway(self, value: Optional[pulumi.Input['SubscriptionSubscriptionPaymentGatewayArgs']]):
        pulumi.set(self, "payment_gateway", value)

    @property
    @pulumi.getter(name="paymentOptions")
    def payment_options(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['SubscriptionSubscriptionPaymentOptionArgs']]]]:
        """
        (Updatable) Payment option list of a subscription.
        """
        return pulumi.get(self, "payment_options")

    @payment_options.setter
    def payment_options(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['SubscriptionSubscriptionPaymentOptionArgs']]]]):
        pulumi.set(self, "payment_options", value)

    @property
    @pulumi.getter(name="planType")
    def plan_type(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Subscription plan type.
        """
        return pulumi.get(self, "plan_type")

    @plan_type.setter
    def plan_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "plan_type", value)

    @property
    @pulumi.getter(name="shipToCustAcctRoleId")
    def ship_to_cust_acct_role_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Ship to customer account role.
        """
        return pulumi.get(self, "ship_to_cust_acct_role_id")

    @ship_to_cust_acct_role_id.setter
    def ship_to_cust_acct_role_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ship_to_cust_acct_role_id", value)

    @property
    @pulumi.getter(name="shipToCustAcctSiteId")
    def ship_to_cust_acct_site_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Ship to customer account site address id.
        """
        return pulumi.get(self, "ship_to_cust_acct_site_id")

    @ship_to_cust_acct_site_id.setter
    def ship_to_cust_acct_site_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ship_to_cust_acct_site_id", value)

    @property
    @pulumi.getter(name="taxInfo")
    def tax_info(self) -> Optional[pulumi.Input['SubscriptionSubscriptionTaxInfoArgs']]:
        """
        (Updatable) Tax details.
        """
        return pulumi.get(self, "tax_info")

    @tax_info.setter
    def tax_info(self, value: Optional[pulumi.Input['SubscriptionSubscriptionTaxInfoArgs']]):
        pulumi.set(self, "tax_info", value)

    @property
    @pulumi.getter(name="timePlanUpgrade")
    def time_plan_upgrade(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Date of upgrade/conversion when planType changed from FREE_TIER to PAYG
        """
        return pulumi.get(self, "time_plan_upgrade")

    @time_plan_upgrade.setter
    def time_plan_upgrade(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_plan_upgrade", value)

    @property
    @pulumi.getter(name="timeStart")
    def time_start(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Start date of the subscription.
        """
        return pulumi.get(self, "time_start")

    @time_start.setter
    def time_start(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_start", value)

    @property
    @pulumi.getter(name="upgradeState")
    def upgrade_state(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Status of the upgrade.
        """
        return pulumi.get(self, "upgrade_state")

    @upgrade_state.setter
    def upgrade_state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "upgrade_state", value)

    @property
    @pulumi.getter(name="upgradeStateDetails")
    def upgrade_state_details(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) This field is used to describe the Upgrade State in case of error (E.g. Upgrade failure caused by interfacing Tax details- TaxError)
        """
        return pulumi.get(self, "upgrade_state_details")

    @upgrade_state_details.setter
    def upgrade_state_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "upgrade_state_details", value)


@pulumi.input_type
class SubscriptionSubscriptionBillingAddressArgs:
    def __init__(__self__, *,
                 address_key: Optional[pulumi.Input[str]] = None,
                 city: Optional[pulumi.Input[str]] = None,
                 company_name: Optional[pulumi.Input[str]] = None,
                 country: Optional[pulumi.Input[str]] = None,
                 email_address: Optional[pulumi.Input[str]] = None,
                 first_name: Optional[pulumi.Input[str]] = None,
                 last_name: Optional[pulumi.Input[str]] = None,
                 line1: Optional[pulumi.Input[str]] = None,
                 line2: Optional[pulumi.Input[str]] = None,
                 postal_code: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] address_key: (Updatable) Address identifier.
        :param pulumi.Input[str] city: (Updatable) Name of the city.
        :param pulumi.Input[str] company_name: (Updatable) Name of the customer company.
        :param pulumi.Input[str] country: (Updatable) Country of the address.
        :param pulumi.Input[str] email_address: (Updatable) The email address of the paypal user.
        :param pulumi.Input[str] first_name: (Updatable) First name of the paypal user.
        :param pulumi.Input[str] last_name: (Updatable) Last name of the paypal user.
        :param pulumi.Input[str] line1: (Updatable) Address line 1.
        :param pulumi.Input[str] line2: (Updatable) Address line 2.
        :param pulumi.Input[str] postal_code: (Updatable) Post code of the address.
        :param pulumi.Input[str] state: (Updatable) State of the address.
        """
        if address_key is not None:
            pulumi.set(__self__, "address_key", address_key)
        if city is not None:
            pulumi.set(__self__, "city", city)
        if company_name is not None:
            pulumi.set(__self__, "company_name", company_name)
        if country is not None:
            pulumi.set(__self__, "country", country)
        if email_address is not None:
            pulumi.set(__self__, "email_address", email_address)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)
        if line1 is not None:
            pulumi.set(__self__, "line1", line1)
        if line2 is not None:
            pulumi.set(__self__, "line2", line2)
        if postal_code is not None:
            pulumi.set(__self__, "postal_code", postal_code)
        if state is not None:
            pulumi.set(__self__, "state", state)

    @property
    @pulumi.getter(name="addressKey")
    def address_key(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Address identifier.
        """
        return pulumi.get(self, "address_key")

    @address_key.setter
    def address_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "address_key", value)

    @property
    @pulumi.getter
    def city(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Name of the city.
        """
        return pulumi.get(self, "city")

    @city.setter
    def city(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "city", value)

    @property
    @pulumi.getter(name="companyName")
    def company_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Name of the customer company.
        """
        return pulumi.get(self, "company_name")

    @company_name.setter
    def company_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "company_name", value)

    @property
    @pulumi.getter
    def country(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Country of the address.
        """
        return pulumi.get(self, "country")

    @country.setter
    def country(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "country", value)

    @property
    @pulumi.getter(name="emailAddress")
    def email_address(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The email address of the paypal user.
        """
        return pulumi.get(self, "email_address")

    @email_address.setter
    def email_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email_address", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) First name of the paypal user.
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Last name of the paypal user.
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_name", value)

    @property
    @pulumi.getter
    def line1(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Address line 1.
        """
        return pulumi.get(self, "line1")

    @line1.setter
    def line1(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "line1", value)

    @property
    @pulumi.getter
    def line2(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Address line 2.
        """
        return pulumi.get(self, "line2")

    @line2.setter
    def line2(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "line2", value)

    @property
    @pulumi.getter(name="postalCode")
    def postal_code(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Post code of the address.
        """
        return pulumi.get(self, "postal_code")

    @postal_code.setter
    def postal_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "postal_code", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) State of the address.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)


@pulumi.input_type
class SubscriptionSubscriptionPaymentGatewayArgs:
    def __init__(__self__, *,
                 merchant_defined_data: Optional[pulumi.Input['SubscriptionSubscriptionPaymentGatewayMerchantDefinedDataArgs']] = None):
        """
        :param pulumi.Input['SubscriptionSubscriptionPaymentGatewayMerchantDefinedDataArgs'] merchant_defined_data: (Updatable) Merchant details.
        """
        if merchant_defined_data is not None:
            pulumi.set(__self__, "merchant_defined_data", merchant_defined_data)

    @property
    @pulumi.getter(name="merchantDefinedData")
    def merchant_defined_data(self) -> Optional[pulumi.Input['SubscriptionSubscriptionPaymentGatewayMerchantDefinedDataArgs']]:
        """
        (Updatable) Merchant details.
        """
        return pulumi.get(self, "merchant_defined_data")

    @merchant_defined_data.setter
    def merchant_defined_data(self, value: Optional[pulumi.Input['SubscriptionSubscriptionPaymentGatewayMerchantDefinedDataArgs']]):
        pulumi.set(self, "merchant_defined_data", value)


@pulumi.input_type
class SubscriptionSubscriptionPaymentGatewayMerchantDefinedDataArgs:
    def __init__(__self__, *,
                 cloud_account_name: Optional[pulumi.Input[str]] = None,
                 promo_type: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] cloud_account_name: (Updatable) Cloud account name.
        :param pulumi.Input[str] promo_type: (Updatable) Promotion type code.
        """
        if cloud_account_name is not None:
            pulumi.set(__self__, "cloud_account_name", cloud_account_name)
        if promo_type is not None:
            pulumi.set(__self__, "promo_type", promo_type)

    @property
    @pulumi.getter(name="cloudAccountName")
    def cloud_account_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Cloud account name.
        """
        return pulumi.get(self, "cloud_account_name")

    @cloud_account_name.setter
    def cloud_account_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "cloud_account_name", value)

    @property
    @pulumi.getter(name="promoType")
    def promo_type(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Promotion type code.
        """
        return pulumi.get(self, "promo_type")

    @promo_type.setter
    def promo_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "promo_type", value)


@pulumi.input_type
class SubscriptionSubscriptionPaymentOptionArgs:
    def __init__(__self__, *,
                 payment_method: pulumi.Input[str],
                 credit_card_type: Optional[pulumi.Input[str]] = None,
                 email_address: Optional[pulumi.Input[str]] = None,
                 ext_billing_agreement_id: Optional[pulumi.Input[str]] = None,
                 first_name: Optional[pulumi.Input[str]] = None,
                 last_digits: Optional[pulumi.Input[str]] = None,
                 last_name: Optional[pulumi.Input[str]] = None,
                 name_on_card: Optional[pulumi.Input[str]] = None,
                 time_expiration: Optional[pulumi.Input[str]] = None,
                 wallet_instrument_id: Optional[pulumi.Input[str]] = None,
                 wallet_transaction_id: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] payment_method: (Updatable) Payment method
        :param pulumi.Input[str] credit_card_type: (Updatable) Credit card type.
        :param pulumi.Input[str] email_address: (Updatable) The email address of the paypal user.
        :param pulumi.Input[str] ext_billing_agreement_id: (Updatable) Agreement id for the paypal account.
        :param pulumi.Input[str] first_name: (Updatable) First name of the paypal user.
        :param pulumi.Input[str] last_digits: (Updatable) Last four digits of the card.
        :param pulumi.Input[str] last_name: (Updatable) Last name of the paypal user.
        :param pulumi.Input[str] name_on_card: (Updatable) Name on the credit card.
        :param pulumi.Input[str] time_expiration: (Updatable) Expired date of the credit card.
        :param pulumi.Input[str] wallet_instrument_id: (Updatable) Wallet instrument internal id.
        :param pulumi.Input[str] wallet_transaction_id: (Updatable) Wallet transaction id.
        """
        pulumi.set(__self__, "payment_method", payment_method)
        if credit_card_type is not None:
            pulumi.set(__self__, "credit_card_type", credit_card_type)
        if email_address is not None:
            pulumi.set(__self__, "email_address", email_address)
        if ext_billing_agreement_id is not None:
            pulumi.set(__self__, "ext_billing_agreement_id", ext_billing_agreement_id)
        if first_name is not None:
            pulumi.set(__self__, "first_name", first_name)
        if last_digits is not None:
            pulumi.set(__self__, "last_digits", last_digits)
        if last_name is not None:
            pulumi.set(__self__, "last_name", last_name)
        if name_on_card is not None:
            pulumi.set(__self__, "name_on_card", name_on_card)
        if time_expiration is not None:
            pulumi.set(__self__, "time_expiration", time_expiration)
        if wallet_instrument_id is not None:
            pulumi.set(__self__, "wallet_instrument_id", wallet_instrument_id)
        if wallet_transaction_id is not None:
            pulumi.set(__self__, "wallet_transaction_id", wallet_transaction_id)

    @property
    @pulumi.getter(name="paymentMethod")
    def payment_method(self) -> pulumi.Input[str]:
        """
        (Updatable) Payment method
        """
        return pulumi.get(self, "payment_method")

    @payment_method.setter
    def payment_method(self, value: pulumi.Input[str]):
        pulumi.set(self, "payment_method", value)

    @property
    @pulumi.getter(name="creditCardType")
    def credit_card_type(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Credit card type.
        """
        return pulumi.get(self, "credit_card_type")

    @credit_card_type.setter
    def credit_card_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "credit_card_type", value)

    @property
    @pulumi.getter(name="emailAddress")
    def email_address(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The email address of the paypal user.
        """
        return pulumi.get(self, "email_address")

    @email_address.setter
    def email_address(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "email_address", value)

    @property
    @pulumi.getter(name="extBillingAgreementId")
    def ext_billing_agreement_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Agreement id for the paypal account.
        """
        return pulumi.get(self, "ext_billing_agreement_id")

    @ext_billing_agreement_id.setter
    def ext_billing_agreement_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ext_billing_agreement_id", value)

    @property
    @pulumi.getter(name="firstName")
    def first_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) First name of the paypal user.
        """
        return pulumi.get(self, "first_name")

    @first_name.setter
    def first_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "first_name", value)

    @property
    @pulumi.getter(name="lastDigits")
    def last_digits(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Last four digits of the card.
        """
        return pulumi.get(self, "last_digits")

    @last_digits.setter
    def last_digits(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_digits", value)

    @property
    @pulumi.getter(name="lastName")
    def last_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Last name of the paypal user.
        """
        return pulumi.get(self, "last_name")

    @last_name.setter
    def last_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "last_name", value)

    @property
    @pulumi.getter(name="nameOnCard")
    def name_on_card(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Name on the credit card.
        """
        return pulumi.get(self, "name_on_card")

    @name_on_card.setter
    def name_on_card(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "name_on_card", value)

    @property
    @pulumi.getter(name="timeExpiration")
    def time_expiration(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Expired date of the credit card.
        """
        return pulumi.get(self, "time_expiration")

    @time_expiration.setter
    def time_expiration(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_expiration", value)

    @property
    @pulumi.getter(name="walletInstrumentId")
    def wallet_instrument_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Wallet instrument internal id.
        """
        return pulumi.get(self, "wallet_instrument_id")

    @wallet_instrument_id.setter
    def wallet_instrument_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "wallet_instrument_id", value)

    @property
    @pulumi.getter(name="walletTransactionId")
    def wallet_transaction_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Wallet transaction id.
        """
        return pulumi.get(self, "wallet_transaction_id")

    @wallet_transaction_id.setter
    def wallet_transaction_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "wallet_transaction_id", value)


@pulumi.input_type
class SubscriptionSubscriptionTaxInfoArgs:
    def __init__(__self__, *,
                 no_tax_reason_code: Optional[pulumi.Input[str]] = None,
                 no_tax_reason_code_details: Optional[pulumi.Input[str]] = None,
                 tax_cnpj: Optional[pulumi.Input[str]] = None,
                 tax_payer_id: Optional[pulumi.Input[str]] = None,
                 tax_reg_number: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] no_tax_reason_code: (Updatable) Tax exemption reason code.
        :param pulumi.Input[str] no_tax_reason_code_details: (Updatable) Tax exemption reason description.
        :param pulumi.Input[str] tax_cnpj: (Updatable) Brazilian companies' CNPJ number.
        :param pulumi.Input[str] tax_payer_id: (Updatable) Tay payer identifier.
        :param pulumi.Input[str] tax_reg_number: (Updatable) Tax registration number.
        """
        if no_tax_reason_code is not None:
            pulumi.set(__self__, "no_tax_reason_code", no_tax_reason_code)
        if no_tax_reason_code_details is not None:
            pulumi.set(__self__, "no_tax_reason_code_details", no_tax_reason_code_details)
        if tax_cnpj is not None:
            pulumi.set(__self__, "tax_cnpj", tax_cnpj)
        if tax_payer_id is not None:
            pulumi.set(__self__, "tax_payer_id", tax_payer_id)
        if tax_reg_number is not None:
            pulumi.set(__self__, "tax_reg_number", tax_reg_number)

    @property
    @pulumi.getter(name="noTaxReasonCode")
    def no_tax_reason_code(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Tax exemption reason code.
        """
        return pulumi.get(self, "no_tax_reason_code")

    @no_tax_reason_code.setter
    def no_tax_reason_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "no_tax_reason_code", value)

    @property
    @pulumi.getter(name="noTaxReasonCodeDetails")
    def no_tax_reason_code_details(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Tax exemption reason description.
        """
        return pulumi.get(self, "no_tax_reason_code_details")

    @no_tax_reason_code_details.setter
    def no_tax_reason_code_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "no_tax_reason_code_details", value)

    @property
    @pulumi.getter(name="taxCnpj")
    def tax_cnpj(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Brazilian companies' CNPJ number.
        """
        return pulumi.get(self, "tax_cnpj")

    @tax_cnpj.setter
    def tax_cnpj(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tax_cnpj", value)

    @property
    @pulumi.getter(name="taxPayerId")
    def tax_payer_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Tay payer identifier.
        """
        return pulumi.get(self, "tax_payer_id")

    @tax_payer_id.setter
    def tax_payer_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tax_payer_id", value)

    @property
    @pulumi.getter(name="taxRegNumber")
    def tax_reg_number(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Tax registration number.
        """
        return pulumi.get(self, "tax_reg_number")

    @tax_reg_number.setter
    def tax_reg_number(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tax_reg_number", value)


@pulumi.input_type
class SubscriptionTaxInfoArgs:
    def __init__(__self__, *,
                 no_tax_reason_code: Optional[pulumi.Input[str]] = None,
                 no_tax_reason_code_details: Optional[pulumi.Input[str]] = None,
                 tax_cnpj: Optional[pulumi.Input[str]] = None,
                 tax_payer_id: Optional[pulumi.Input[str]] = None,
                 tax_reg_number: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] no_tax_reason_code: (Updatable) Tax exemption reason code.
        :param pulumi.Input[str] no_tax_reason_code_details: (Updatable) Tax exemption reason description.
        :param pulumi.Input[str] tax_cnpj: (Updatable) Brazilian companies' CNPJ number.
        :param pulumi.Input[str] tax_payer_id: (Updatable) Tay payer identifier.
        :param pulumi.Input[str] tax_reg_number: (Updatable) Tax registration number.
        """
        if no_tax_reason_code is not None:
            pulumi.set(__self__, "no_tax_reason_code", no_tax_reason_code)
        if no_tax_reason_code_details is not None:
            pulumi.set(__self__, "no_tax_reason_code_details", no_tax_reason_code_details)
        if tax_cnpj is not None:
            pulumi.set(__self__, "tax_cnpj", tax_cnpj)
        if tax_payer_id is not None:
            pulumi.set(__self__, "tax_payer_id", tax_payer_id)
        if tax_reg_number is not None:
            pulumi.set(__self__, "tax_reg_number", tax_reg_number)

    @property
    @pulumi.getter(name="noTaxReasonCode")
    def no_tax_reason_code(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Tax exemption reason code.
        """
        return pulumi.get(self, "no_tax_reason_code")

    @no_tax_reason_code.setter
    def no_tax_reason_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "no_tax_reason_code", value)

    @property
    @pulumi.getter(name="noTaxReasonCodeDetails")
    def no_tax_reason_code_details(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Tax exemption reason description.
        """
        return pulumi.get(self, "no_tax_reason_code_details")

    @no_tax_reason_code_details.setter
    def no_tax_reason_code_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "no_tax_reason_code_details", value)

    @property
    @pulumi.getter(name="taxCnpj")
    def tax_cnpj(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Brazilian companies' CNPJ number.
        """
        return pulumi.get(self, "tax_cnpj")

    @tax_cnpj.setter
    def tax_cnpj(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tax_cnpj", value)

    @property
    @pulumi.getter(name="taxPayerId")
    def tax_payer_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Tay payer identifier.
        """
        return pulumi.get(self, "tax_payer_id")

    @tax_payer_id.setter
    def tax_payer_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tax_payer_id", value)

    @property
    @pulumi.getter(name="taxRegNumber")
    def tax_reg_number(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) Tax registration number.
        """
        return pulumi.get(self, "tax_reg_number")

    @tax_reg_number.setter
    def tax_reg_number(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tax_reg_number", value)


@pulumi.input_type
class GetInvoicesFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        """
        :param str name: Name of the currency
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the currency
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)


@pulumi.input_type
class GetInvoicesInvoiceLinesFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        """
        :param str name: Name of the currency
        """
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        Name of the currency
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)


@pulumi.input_type
class GetSubscriptionsFilterArgs:
    def __init__(__self__, *,
                 name: str,
                 values: Sequence[str],
                 regex: Optional[bool] = None):
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "values", values)
        if regex is not None:
            pulumi.set(__self__, "regex", regex)

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: str):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter
    def values(self) -> Sequence[str]:
        return pulumi.get(self, "values")

    @values.setter
    def values(self, value: Sequence[str]):
        pulumi.set(self, "values", value)

    @property
    @pulumi.getter
    def regex(self) -> Optional[bool]:
        return pulumi.get(self, "regex")

    @regex.setter
    def regex(self, value: Optional[bool]):
        pulumi.set(self, "regex", value)





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .container_configuration import *
from .container_image_signature import *
from .container_repository import *
from .generic_artifact import *
from .get_container_configuration import *
from .get_container_image import *
from .get_container_image_signature import *
from .get_container_images import *
from .get_container_repositories import *
from .get_container_repository import *
from .get_container_signatures import *
from .get_generic_artifact import *
from .get_generic_artifacts import *
from .get_repositories import *
from .get_repository import *
from .repository import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

from .. import _utilities
import typing
# Export this package's modules as members:
from .api import *
from .certificate import *
from .deployment import *
from .gateway import *
from .get_api import *
from .get_api_content import *
from .get_api_deployment_specification import *
from .get_api_validation import *
from .get_apis import *
from .get_certificate import *
from .get_certificates import *
from .get_deployment import *
from .get_deployments import *
from .get_gateway import *
from .get_gateways import *
from .get_subscriber import *
from .get_subscribers import *
from .get_usage_plan import *
from .get_usage_plans import *
from .subscriber import *
from .usage_plan import *
from ._inputs import *
from . import outputs



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['DrProtectionGroupArgs', 'DrProtectionGroup']

@pulumi.input_type
class DrProtectionGroupArgs:
    def __init__(__self__, *,
                 compartment_id: pulumi.Input[str],
                 display_name: pulumi.Input[str],
                 log_location: pulumi.Input['DrProtectionGroupLogLocationArgs'],
                 association: Optional[pulumi.Input['DrProtectionGroupAssociationArgs']] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 disassociate_trigger: Optional[pulumi.Input[int]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input['DrProtectionGroupMemberArgs']]]] = None):
        """
        The set of arguments for constructing a DrProtectionGroup resource.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment in which to create the DR Protection Group.  Example: `ocid1.compartment.oc1..exampleocid1`
        :param pulumi.Input[str] display_name: (Updatable) The display name of the DR Protection Group.  Example: `EBS PHX DRPG`
        :param pulumi.Input['DrProtectionGroupLogLocationArgs'] log_location: (Updatable) Information about creating an Object Storage log location for a DR Protection Group.
        :param pulumi.Input['DrProtectionGroupAssociationArgs'] association: The details for associating this DR Protection Group with a peer (remote) DR Protection Group.
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[int] disassociate_trigger: (Updatable) An optional property when incremented triggers Disassociate. Could be set to any integer value.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"Department": "Finance"}`
        :param pulumi.Input[Sequence[pulumi.Input['DrProtectionGroupMemberArgs']]] members: (Updatable) A list of DR Protection Group members.
        """
        pulumi.set(__self__, "compartment_id", compartment_id)
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "log_location", log_location)
        if association is not None:
            pulumi.set(__self__, "association", association)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if disassociate_trigger is not None:
            pulumi.set(__self__, "disassociate_trigger", disassociate_trigger)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if members is not None:
            pulumi.set(__self__, "members", members)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Input[str]:
        """
        (Updatable) The OCID of the compartment in which to create the DR Protection Group.  Example: `ocid1.compartment.oc1..exampleocid1`
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Input[str]:
        """
        (Updatable) The display name of the DR Protection Group.  Example: `EBS PHX DRPG`
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="logLocation")
    def log_location(self) -> pulumi.Input['DrProtectionGroupLogLocationArgs']:
        """
        (Updatable) Information about creating an Object Storage log location for a DR Protection Group.
        """
        return pulumi.get(self, "log_location")

    @log_location.setter
    def log_location(self, value: pulumi.Input['DrProtectionGroupLogLocationArgs']):
        pulumi.set(self, "log_location", value)

    @property
    @pulumi.getter
    def association(self) -> Optional[pulumi.Input['DrProtectionGroupAssociationArgs']]:
        """
        The details for associating this DR Protection Group with a peer (remote) DR Protection Group.
        """
        return pulumi.get(self, "association")

    @association.setter
    def association(self, value: Optional[pulumi.Input['DrProtectionGroupAssociationArgs']]):
        pulumi.set(self, "association", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="disassociateTrigger")
    def disassociate_trigger(self) -> Optional[pulumi.Input[int]]:
        """
        (Updatable) An optional property when incremented triggers Disassociate. Could be set to any integer value.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "disassociate_trigger")

    @disassociate_trigger.setter
    def disassociate_trigger(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "disassociate_trigger", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DrProtectionGroupMemberArgs']]]]:
        """
        (Updatable) A list of DR Protection Group members.
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DrProtectionGroupMemberArgs']]]]):
        pulumi.set(self, "members", value)


@pulumi.input_type
class _DrProtectionGroupState:
    def __init__(__self__, *,
                 association: Optional[pulumi.Input['DrProtectionGroupAssociationArgs']] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 disassociate_trigger: Optional[pulumi.Input[int]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 life_cycle_details: Optional[pulumi.Input[str]] = None,
                 log_location: Optional[pulumi.Input['DrProtectionGroupLogLocationArgs']] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input['DrProtectionGroupMemberArgs']]]] = None,
                 peer_id: Optional[pulumi.Input[str]] = None,
                 peer_region: Optional[pulumi.Input[str]] = None,
                 role: Optional[pulumi.Input[str]] = None,
                 state: Optional[pulumi.Input[str]] = None,
                 system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 time_created: Optional[pulumi.Input[str]] = None,
                 time_updated: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering DrProtectionGroup resources.
        :param pulumi.Input['DrProtectionGroupAssociationArgs'] association: The details for associating this DR Protection Group with a peer (remote) DR Protection Group.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment in which to create the DR Protection Group.  Example: `ocid1.compartment.oc1..exampleocid1`
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[int] disassociate_trigger: (Updatable) An optional property when incremented triggers Disassociate. Could be set to any integer value.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] display_name: (Updatable) The display name of the DR Protection Group.  Example: `EBS PHX DRPG`
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] life_cycle_details: A message describing the DR Protection Group's current state in more detail.
        :param pulumi.Input['DrProtectionGroupLogLocationArgs'] log_location: (Updatable) Information about creating an Object Storage log location for a DR Protection Group.
        :param pulumi.Input[Sequence[pulumi.Input['DrProtectionGroupMemberArgs']]] members: (Updatable) A list of DR Protection Group members.
        :param pulumi.Input[str] peer_id: The OCID of the peer (remote) DR Protection Group.  Example: `ocid1.drprotectiongroup.oc1.iad.exampleocid2`
        :param pulumi.Input[str] peer_region: The region of the peer (remote) DR Protection Group.  Example: `us-ashburn-1`
        :param pulumi.Input[str] role: The role of this DR Protection Group.
        :param pulumi.Input[str] state: The current state of the DR Protection Group.
        :param pulumi.Input[Mapping[str, Any]] system_tags: Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param pulumi.Input[str] time_created: The date and time the DR Protection Group was created. An RFC3339 formatted datetime string.  Example: `2019-03-29T09:36:42Z`
        :param pulumi.Input[str] time_updated: The date and time the DR Protection Group was updated. An RFC3339 formatted datetime string.  Example: `2019-03-29T09:36:42Z`
        """
        if association is not None:
            pulumi.set(__self__, "association", association)
        if compartment_id is not None:
            pulumi.set(__self__, "compartment_id", compartment_id)
        if defined_tags is not None:
            pulumi.set(__self__, "defined_tags", defined_tags)
        if disassociate_trigger is not None:
            pulumi.set(__self__, "disassociate_trigger", disassociate_trigger)
        if display_name is not None:
            pulumi.set(__self__, "display_name", display_name)
        if freeform_tags is not None:
            pulumi.set(__self__, "freeform_tags", freeform_tags)
        if life_cycle_details is not None:
            pulumi.set(__self__, "life_cycle_details", life_cycle_details)
        if log_location is not None:
            pulumi.set(__self__, "log_location", log_location)
        if members is not None:
            pulumi.set(__self__, "members", members)
        if peer_id is not None:
            pulumi.set(__self__, "peer_id", peer_id)
        if peer_region is not None:
            pulumi.set(__self__, "peer_region", peer_region)
        if role is not None:
            pulumi.set(__self__, "role", role)
        if state is not None:
            pulumi.set(__self__, "state", state)
        if system_tags is not None:
            pulumi.set(__self__, "system_tags", system_tags)
        if time_created is not None:
            pulumi.set(__self__, "time_created", time_created)
        if time_updated is not None:
            pulumi.set(__self__, "time_updated", time_updated)

    @property
    @pulumi.getter
    def association(self) -> Optional[pulumi.Input['DrProtectionGroupAssociationArgs']]:
        """
        The details for associating this DR Protection Group with a peer (remote) DR Protection Group.
        """
        return pulumi.get(self, "association")

    @association.setter
    def association(self, value: Optional[pulumi.Input['DrProtectionGroupAssociationArgs']]):
        pulumi.set(self, "association", value)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The OCID of the compartment in which to create the DR Protection Group.  Example: `ocid1.compartment.oc1..exampleocid1`
        """
        return pulumi.get(self, "compartment_id")

    @compartment_id.setter
    def compartment_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "compartment_id", value)

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @defined_tags.setter
    def defined_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "defined_tags", value)

    @property
    @pulumi.getter(name="disassociateTrigger")
    def disassociate_trigger(self) -> Optional[pulumi.Input[int]]:
        """
        (Updatable) An optional property when incremented triggers Disassociate. Could be set to any integer value.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "disassociate_trigger")

    @disassociate_trigger.setter
    def disassociate_trigger(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "disassociate_trigger", value)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[pulumi.Input[str]]:
        """
        (Updatable) The display name of the DR Protection Group.  Example: `EBS PHX DRPG`
        """
        return pulumi.get(self, "display_name")

    @display_name.setter
    def display_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "display_name", value)

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @freeform_tags.setter
    def freeform_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "freeform_tags", value)

    @property
    @pulumi.getter(name="lifeCycleDetails")
    def life_cycle_details(self) -> Optional[pulumi.Input[str]]:
        """
        A message describing the DR Protection Group's current state in more detail.
        """
        return pulumi.get(self, "life_cycle_details")

    @life_cycle_details.setter
    def life_cycle_details(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "life_cycle_details", value)

    @property
    @pulumi.getter(name="logLocation")
    def log_location(self) -> Optional[pulumi.Input['DrProtectionGroupLogLocationArgs']]:
        """
        (Updatable) Information about creating an Object Storage log location for a DR Protection Group.
        """
        return pulumi.get(self, "log_location")

    @log_location.setter
    def log_location(self, value: Optional[pulumi.Input['DrProtectionGroupLogLocationArgs']]):
        pulumi.set(self, "log_location", value)

    @property
    @pulumi.getter
    def members(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['DrProtectionGroupMemberArgs']]]]:
        """
        (Updatable) A list of DR Protection Group members.
        """
        return pulumi.get(self, "members")

    @members.setter
    def members(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['DrProtectionGroupMemberArgs']]]]):
        pulumi.set(self, "members", value)

    @property
    @pulumi.getter(name="peerId")
    def peer_id(self) -> Optional[pulumi.Input[str]]:
        """
        The OCID of the peer (remote) DR Protection Group.  Example: `ocid1.drprotectiongroup.oc1.iad.exampleocid2`
        """
        return pulumi.get(self, "peer_id")

    @peer_id.setter
    def peer_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peer_id", value)

    @property
    @pulumi.getter(name="peerRegion")
    def peer_region(self) -> Optional[pulumi.Input[str]]:
        """
        The region of the peer (remote) DR Protection Group.  Example: `us-ashburn-1`
        """
        return pulumi.get(self, "peer_region")

    @peer_region.setter
    def peer_region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "peer_region", value)

    @property
    @pulumi.getter
    def role(self) -> Optional[pulumi.Input[str]]:
        """
        The role of this DR Protection Group.
        """
        return pulumi.get(self, "role")

    @role.setter
    def role(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role", value)

    @property
    @pulumi.getter
    def state(self) -> Optional[pulumi.Input[str]]:
        """
        The current state of the DR Protection Group.
        """
        return pulumi.get(self, "state")

    @state.setter
    def state(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "state", value)

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> Optional[pulumi.Input[Mapping[str, Any]]]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @system_tags.setter
    def system_tags(self, value: Optional[pulumi.Input[Mapping[str, Any]]]):
        pulumi.set(self, "system_tags", value)

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time the DR Protection Group was created. An RFC3339 formatted datetime string.  Example: `2019-03-29T09:36:42Z`
        """
        return pulumi.get(self, "time_created")

    @time_created.setter
    def time_created(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_created", value)

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> Optional[pulumi.Input[str]]:
        """
        The date and time the DR Protection Group was updated. An RFC3339 formatted datetime string.  Example: `2019-03-29T09:36:42Z`
        """
        return pulumi.get(self, "time_updated")

    @time_updated.setter
    def time_updated(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "time_updated", value)


class DrProtectionGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 association: Optional[pulumi.Input[pulumi.InputType['DrProtectionGroupAssociationArgs']]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 disassociate_trigger: Optional[pulumi.Input[int]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 log_location: Optional[pulumi.Input[pulumi.InputType['DrProtectionGroupLogLocationArgs']]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DrProtectionGroupMemberArgs']]]]] = None,
                 __props__=None):
        """
        This resource provides the Dr Protection Group resource in Oracle Cloud Infrastructure Disaster Recovery service.

        Create a new DR Protection Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_dr_protection_group = oci.disaster_recovery.DrProtectionGroup("testDrProtectionGroup",
            compartment_id=var["compartment_id"],
            display_name=var["dr_protection_group_display_name"],
            log_location=oci.disaster_recovery.DrProtectionGroupLogLocationArgs(
                bucket=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            association=oci.disaster_recovery.DrProtectionGroupAssociationArgs(
                role=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                peer_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                peer_region=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            defined_tags={
                "Operations.CostCenter": "42",
            },
            freeform_tags={
                "Department": "Finance",
            },
            members=[oci.disaster_recovery.DrProtectionGroupMemberArgs(
                member_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                member_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                destination_compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                destination_dedicated_vm_host_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                is_movable=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                password_vault_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                vnic_mappings=[oci.disaster_recovery.DrProtectionGroupMemberVnicMappingArgs(
                    destination_nsg_id_lists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    destination_subnet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    source_vnic_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
            )])
        ```

        ## Import

        DrProtectionGroups can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:DisasterRecovery/drProtectionGroup:DrProtectionGroup test_dr_protection_group "id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['DrProtectionGroupAssociationArgs']] association: The details for associating this DR Protection Group with a peer (remote) DR Protection Group.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment in which to create the DR Protection Group.  Example: `ocid1.compartment.oc1..exampleocid1`
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[int] disassociate_trigger: (Updatable) An optional property when incremented triggers Disassociate. Could be set to any integer value.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] display_name: (Updatable) The display name of the DR Protection Group.  Example: `EBS PHX DRPG`
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"Department": "Finance"}`
        :param pulumi.Input[pulumi.InputType['DrProtectionGroupLogLocationArgs']] log_location: (Updatable) Information about creating an Object Storage log location for a DR Protection Group.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DrProtectionGroupMemberArgs']]]] members: (Updatable) A list of DR Protection Group members.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DrProtectionGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        This resource provides the Dr Protection Group resource in Oracle Cloud Infrastructure Disaster Recovery service.

        Create a new DR Protection Group.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_oci as oci

        test_dr_protection_group = oci.disaster_recovery.DrProtectionGroup("testDrProtectionGroup",
            compartment_id=var["compartment_id"],
            display_name=var["dr_protection_group_display_name"],
            log_location=oci.disaster_recovery.DrProtectionGroupLogLocationArgs(
                bucket=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                namespace=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            association=oci.disaster_recovery.DrProtectionGroupAssociationArgs(
                role=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                peer_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                peer_region=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
            ),
            defined_tags={
                "Operations.CostCenter": "42",
            },
            freeform_tags={
                "Department": "Finance",
            },
            members=[oci.disaster_recovery.DrProtectionGroupMemberArgs(
                member_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                member_type=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                destination_compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                destination_dedicated_vm_host_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                is_movable=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                password_vault_secret_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                vnic_mappings=[oci.disaster_recovery.DrProtectionGroupMemberVnicMappingArgs(
                    destination_nsg_id_lists=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    destination_subnet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                    source_vnic_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
                )],
            )])
        ```

        ## Import

        DrProtectionGroups can be imported using the `id`, e.g.

        ```sh
         $ pulumi import oci:DisasterRecovery/drProtectionGroup:DrProtectionGroup test_dr_protection_group "id"
        ```

        :param str resource_name: The name of the resource.
        :param DrProtectionGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DrProtectionGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 association: Optional[pulumi.Input[pulumi.InputType['DrProtectionGroupAssociationArgs']]] = None,
                 compartment_id: Optional[pulumi.Input[str]] = None,
                 defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 disassociate_trigger: Optional[pulumi.Input[int]] = None,
                 display_name: Optional[pulumi.Input[str]] = None,
                 freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
                 log_location: Optional[pulumi.Input[pulumi.InputType['DrProtectionGroupLogLocationArgs']]] = None,
                 members: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DrProtectionGroupMemberArgs']]]]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DrProtectionGroupArgs.__new__(DrProtectionGroupArgs)

            __props__.__dict__["association"] = association
            if compartment_id is None and not opts.urn:
                raise TypeError("Missing required property 'compartment_id'")
            __props__.__dict__["compartment_id"] = compartment_id
            __props__.__dict__["defined_tags"] = defined_tags
            __props__.__dict__["disassociate_trigger"] = disassociate_trigger
            if display_name is None and not opts.urn:
                raise TypeError("Missing required property 'display_name'")
            __props__.__dict__["display_name"] = display_name
            __props__.__dict__["freeform_tags"] = freeform_tags
            if log_location is None and not opts.urn:
                raise TypeError("Missing required property 'log_location'")
            __props__.__dict__["log_location"] = log_location
            __props__.__dict__["members"] = members
            __props__.__dict__["life_cycle_details"] = None
            __props__.__dict__["peer_id"] = None
            __props__.__dict__["peer_region"] = None
            __props__.__dict__["role"] = None
            __props__.__dict__["state"] = None
            __props__.__dict__["system_tags"] = None
            __props__.__dict__["time_created"] = None
            __props__.__dict__["time_updated"] = None
        super(DrProtectionGroup, __self__).__init__(
            'oci:DisasterRecovery/drProtectionGroup:DrProtectionGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            association: Optional[pulumi.Input[pulumi.InputType['DrProtectionGroupAssociationArgs']]] = None,
            compartment_id: Optional[pulumi.Input[str]] = None,
            defined_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            disassociate_trigger: Optional[pulumi.Input[int]] = None,
            display_name: Optional[pulumi.Input[str]] = None,
            freeform_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            life_cycle_details: Optional[pulumi.Input[str]] = None,
            log_location: Optional[pulumi.Input[pulumi.InputType['DrProtectionGroupLogLocationArgs']]] = None,
            members: Optional[pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DrProtectionGroupMemberArgs']]]]] = None,
            peer_id: Optional[pulumi.Input[str]] = None,
            peer_region: Optional[pulumi.Input[str]] = None,
            role: Optional[pulumi.Input[str]] = None,
            state: Optional[pulumi.Input[str]] = None,
            system_tags: Optional[pulumi.Input[Mapping[str, Any]]] = None,
            time_created: Optional[pulumi.Input[str]] = None,
            time_updated: Optional[pulumi.Input[str]] = None) -> 'DrProtectionGroup':
        """
        Get an existing DrProtectionGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[pulumi.InputType['DrProtectionGroupAssociationArgs']] association: The details for associating this DR Protection Group with a peer (remote) DR Protection Group.
        :param pulumi.Input[str] compartment_id: (Updatable) The OCID of the compartment in which to create the DR Protection Group.  Example: `ocid1.compartment.oc1..exampleocid1`
        :param pulumi.Input[Mapping[str, Any]] defined_tags: (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"Operations.CostCenter": "42"}`
        :param pulumi.Input[int] disassociate_trigger: (Updatable) An optional property when incremented triggers Disassociate. Could be set to any integer value.
               
               
               ** IMPORTANT **
               Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        :param pulumi.Input[str] display_name: (Updatable) The display name of the DR Protection Group.  Example: `EBS PHX DRPG`
        :param pulumi.Input[Mapping[str, Any]] freeform_tags: (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"Department": "Finance"}`
        :param pulumi.Input[str] life_cycle_details: A message describing the DR Protection Group's current state in more detail.
        :param pulumi.Input[pulumi.InputType['DrProtectionGroupLogLocationArgs']] log_location: (Updatable) Information about creating an Object Storage log location for a DR Protection Group.
        :param pulumi.Input[Sequence[pulumi.Input[pulumi.InputType['DrProtectionGroupMemberArgs']]]] members: (Updatable) A list of DR Protection Group members.
        :param pulumi.Input[str] peer_id: The OCID of the peer (remote) DR Protection Group.  Example: `ocid1.drprotectiongroup.oc1.iad.exampleocid2`
        :param pulumi.Input[str] peer_region: The region of the peer (remote) DR Protection Group.  Example: `us-ashburn-1`
        :param pulumi.Input[str] role: The role of this DR Protection Group.
        :param pulumi.Input[str] state: The current state of the DR Protection Group.
        :param pulumi.Input[Mapping[str, Any]] system_tags: Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        :param pulumi.Input[str] time_created: The date and time the DR Protection Group was created. An RFC3339 formatted datetime string.  Example: `2019-03-29T09:36:42Z`
        :param pulumi.Input[str] time_updated: The date and time the DR Protection Group was updated. An RFC3339 formatted datetime string.  Example: `2019-03-29T09:36:42Z`
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DrProtectionGroupState.__new__(_DrProtectionGroupState)

        __props__.__dict__["association"] = association
        __props__.__dict__["compartment_id"] = compartment_id
        __props__.__dict__["defined_tags"] = defined_tags
        __props__.__dict__["disassociate_trigger"] = disassociate_trigger
        __props__.__dict__["display_name"] = display_name
        __props__.__dict__["freeform_tags"] = freeform_tags
        __props__.__dict__["life_cycle_details"] = life_cycle_details
        __props__.__dict__["log_location"] = log_location
        __props__.__dict__["members"] = members
        __props__.__dict__["peer_id"] = peer_id
        __props__.__dict__["peer_region"] = peer_region
        __props__.__dict__["role"] = role
        __props__.__dict__["state"] = state
        __props__.__dict__["system_tags"] = system_tags
        __props__.__dict__["time_created"] = time_created
        __props__.__dict__["time_updated"] = time_updated
        return DrProtectionGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def association(self) -> pulumi.Output['outputs.DrProtectionGroupAssociation']:
        """
        The details for associating this DR Protection Group with a peer (remote) DR Protection Group.
        """
        return pulumi.get(self, "association")

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> pulumi.Output[str]:
        """
        (Updatable) The OCID of the compartment in which to create the DR Protection Group.  Example: `ocid1.compartment.oc1..exampleocid1`
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="definedTags")
    def defined_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Defined tags for this resource. Each key is predefined and scoped to a namespace. Example: `{"Operations.CostCenter": "42"}`
        """
        return pulumi.get(self, "defined_tags")

    @property
    @pulumi.getter(name="disassociateTrigger")
    def disassociate_trigger(self) -> pulumi.Output[Optional[int]]:
        """
        (Updatable) An optional property when incremented triggers Disassociate. Could be set to any integer value.


        ** IMPORTANT **
        Any change to a property that does not support update will force the destruction and recreation of the resource with the new property values
        """
        return pulumi.get(self, "disassociate_trigger")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> pulumi.Output[str]:
        """
        (Updatable) The display name of the DR Protection Group.  Example: `EBS PHX DRPG`
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter(name="freeformTags")
    def freeform_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        (Updatable) Simple key-value pair that is applied without any predefined name, type or scope. Exists for cross-compatibility only. Example: `{"Department": "Finance"}`
        """
        return pulumi.get(self, "freeform_tags")

    @property
    @pulumi.getter(name="lifeCycleDetails")
    def life_cycle_details(self) -> pulumi.Output[str]:
        """
        A message describing the DR Protection Group's current state in more detail.
        """
        return pulumi.get(self, "life_cycle_details")

    @property
    @pulumi.getter(name="logLocation")
    def log_location(self) -> pulumi.Output['outputs.DrProtectionGroupLogLocation']:
        """
        (Updatable) Information about creating an Object Storage log location for a DR Protection Group.
        """
        return pulumi.get(self, "log_location")

    @property
    @pulumi.getter
    def members(self) -> pulumi.Output[Sequence['outputs.DrProtectionGroupMember']]:
        """
        (Updatable) A list of DR Protection Group members.
        """
        return pulumi.get(self, "members")

    @property
    @pulumi.getter(name="peerId")
    def peer_id(self) -> pulumi.Output[str]:
        """
        The OCID of the peer (remote) DR Protection Group.  Example: `ocid1.drprotectiongroup.oc1.iad.exampleocid2`
        """
        return pulumi.get(self, "peer_id")

    @property
    @pulumi.getter(name="peerRegion")
    def peer_region(self) -> pulumi.Output[str]:
        """
        The region of the peer (remote) DR Protection Group.  Example: `us-ashburn-1`
        """
        return pulumi.get(self, "peer_region")

    @property
    @pulumi.getter
    def role(self) -> pulumi.Output[str]:
        """
        The role of this DR Protection Group.
        """
        return pulumi.get(self, "role")

    @property
    @pulumi.getter
    def state(self) -> pulumi.Output[str]:
        """
        The current state of the DR Protection Group.
        """
        return pulumi.get(self, "state")

    @property
    @pulumi.getter(name="systemTags")
    def system_tags(self) -> pulumi.Output[Mapping[str, Any]]:
        """
        Usage of system tag keys. These predefined keys are scoped to namespaces. Example: `{"orcl-cloud.free-tier-retained": "true"}`
        """
        return pulumi.get(self, "system_tags")

    @property
    @pulumi.getter(name="timeCreated")
    def time_created(self) -> pulumi.Output[str]:
        """
        The date and time the DR Protection Group was created. An RFC3339 formatted datetime string.  Example: `2019-03-29T09:36:42Z`
        """
        return pulumi.get(self, "time_created")

    @property
    @pulumi.getter(name="timeUpdated")
    def time_updated(self) -> pulumi.Output[str]:
        """
        The date and time the DR Protection Group was updated. An RFC3339 formatted datetime string.  Example: `2019-03-29T09:36:42Z`
        """
        return pulumi.get(self, "time_updated")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetInstallationSitesResult',
    'AwaitableGetInstallationSitesResult',
    'get_installation_sites',
    'get_installation_sites_output',
]

@pulumi.output_type
class GetInstallationSitesResult:
    """
    A collection of values returned by getInstallationSites.
    """
    def __init__(__self__, application_id=None, filters=None, fleet_id=None, id=None, installation_path=None, installation_site_collections=None, jre_distribution=None, jre_security_status=None, jre_vendor=None, jre_version=None, managed_instance_id=None, os_families=None, path_contains=None, time_end=None, time_start=None):
        if application_id and not isinstance(application_id, str):
            raise TypeError("Expected argument 'application_id' to be a str")
        pulumi.set(__self__, "application_id", application_id)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if fleet_id and not isinstance(fleet_id, str):
            raise TypeError("Expected argument 'fleet_id' to be a str")
        pulumi.set(__self__, "fleet_id", fleet_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if installation_path and not isinstance(installation_path, str):
            raise TypeError("Expected argument 'installation_path' to be a str")
        pulumi.set(__self__, "installation_path", installation_path)
        if installation_site_collections and not isinstance(installation_site_collections, list):
            raise TypeError("Expected argument 'installation_site_collections' to be a list")
        pulumi.set(__self__, "installation_site_collections", installation_site_collections)
        if jre_distribution and not isinstance(jre_distribution, str):
            raise TypeError("Expected argument 'jre_distribution' to be a str")
        pulumi.set(__self__, "jre_distribution", jre_distribution)
        if jre_security_status and not isinstance(jre_security_status, str):
            raise TypeError("Expected argument 'jre_security_status' to be a str")
        pulumi.set(__self__, "jre_security_status", jre_security_status)
        if jre_vendor and not isinstance(jre_vendor, str):
            raise TypeError("Expected argument 'jre_vendor' to be a str")
        pulumi.set(__self__, "jre_vendor", jre_vendor)
        if jre_version and not isinstance(jre_version, str):
            raise TypeError("Expected argument 'jre_version' to be a str")
        pulumi.set(__self__, "jre_version", jre_version)
        if managed_instance_id and not isinstance(managed_instance_id, str):
            raise TypeError("Expected argument 'managed_instance_id' to be a str")
        pulumi.set(__self__, "managed_instance_id", managed_instance_id)
        if os_families and not isinstance(os_families, list):
            raise TypeError("Expected argument 'os_families' to be a list")
        pulumi.set(__self__, "os_families", os_families)
        if path_contains and not isinstance(path_contains, str):
            raise TypeError("Expected argument 'path_contains' to be a str")
        pulumi.set(__self__, "path_contains", path_contains)
        if time_end and not isinstance(time_end, str):
            raise TypeError("Expected argument 'time_end' to be a str")
        pulumi.set(__self__, "time_end", time_end)
        if time_start and not isinstance(time_start, str):
            raise TypeError("Expected argument 'time_start' to be a str")
        pulumi.set(__self__, "time_start", time_start)

    @property
    @pulumi.getter(name="applicationId")
    def application_id(self) -> Optional[str]:
        return pulumi.get(self, "application_id")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetInstallationSitesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter(name="fleetId")
    def fleet_id(self) -> str:
        return pulumi.get(self, "fleet_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="installationPath")
    def installation_path(self) -> Optional[str]:
        return pulumi.get(self, "installation_path")

    @property
    @pulumi.getter(name="installationSiteCollections")
    def installation_site_collections(self) -> Sequence['outputs.GetInstallationSitesInstallationSiteCollectionResult']:
        """
        The list of installation_site_collection.
        """
        return pulumi.get(self, "installation_site_collections")

    @property
    @pulumi.getter(name="jreDistribution")
    def jre_distribution(self) -> Optional[str]:
        return pulumi.get(self, "jre_distribution")

    @property
    @pulumi.getter(name="jreSecurityStatus")
    def jre_security_status(self) -> Optional[str]:
        return pulumi.get(self, "jre_security_status")

    @property
    @pulumi.getter(name="jreVendor")
    def jre_vendor(self) -> Optional[str]:
        return pulumi.get(self, "jre_vendor")

    @property
    @pulumi.getter(name="jreVersion")
    def jre_version(self) -> Optional[str]:
        return pulumi.get(self, "jre_version")

    @property
    @pulumi.getter(name="managedInstanceId")
    def managed_instance_id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the related managed instance.
        """
        return pulumi.get(self, "managed_instance_id")

    @property
    @pulumi.getter(name="osFamilies")
    def os_families(self) -> Optional[Sequence[str]]:
        return pulumi.get(self, "os_families")

    @property
    @pulumi.getter(name="pathContains")
    def path_contains(self) -> Optional[str]:
        return pulumi.get(self, "path_contains")

    @property
    @pulumi.getter(name="timeEnd")
    def time_end(self) -> Optional[str]:
        return pulumi.get(self, "time_end")

    @property
    @pulumi.getter(name="timeStart")
    def time_start(self) -> Optional[str]:
        return pulumi.get(self, "time_start")


class AwaitableGetInstallationSitesResult(GetInstallationSitesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetInstallationSitesResult(
            application_id=self.application_id,
            filters=self.filters,
            fleet_id=self.fleet_id,
            id=self.id,
            installation_path=self.installation_path,
            installation_site_collections=self.installation_site_collections,
            jre_distribution=self.jre_distribution,
            jre_security_status=self.jre_security_status,
            jre_vendor=self.jre_vendor,
            jre_version=self.jre_version,
            managed_instance_id=self.managed_instance_id,
            os_families=self.os_families,
            path_contains=self.path_contains,
            time_end=self.time_end,
            time_start=self.time_start)


def get_installation_sites(application_id: Optional[str] = None,
                           filters: Optional[Sequence[pulumi.InputType['GetInstallationSitesFilterArgs']]] = None,
                           fleet_id: Optional[str] = None,
                           installation_path: Optional[str] = None,
                           jre_distribution: Optional[str] = None,
                           jre_security_status: Optional[str] = None,
                           jre_vendor: Optional[str] = None,
                           jre_version: Optional[str] = None,
                           managed_instance_id: Optional[str] = None,
                           os_families: Optional[Sequence[str]] = None,
                           path_contains: Optional[str] = None,
                           time_end: Optional[str] = None,
                           time_start: Optional[str] = None,
                           opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetInstallationSitesResult:
    """
    This data source provides the list of Fleet Installation Sites in Oracle Cloud Infrastructure Jms service.

    List Java installation sites in a Fleet filtered by query parameters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fleet_installation_sites = oci.Jms.get_installation_sites(fleet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        application_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        installation_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        jre_distribution=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        jre_security_status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        jre_vendor=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        jre_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        managed_instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        os_families=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        path_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_end=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_start=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str application_id: The Fleet-unique identifier of the related application.
    :param str fleet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Fleet.
    :param str installation_path: The file system path of the installation.
    :param str jre_distribution: The distribution of the related Java Runtime.
    :param str jre_security_status: The security status of the Java Runtime.
    :param str jre_vendor: The vendor of the related Java Runtime.
    :param str jre_version: The version of the related Java Runtime.
    :param str managed_instance_id: The Fleet-unique identifier of the related managed instance.
    :param Sequence[str] os_families: The operating system type.
    :param str path_contains: Filter the list with path contains the given value.
    :param str time_end: The end of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
    :param str time_start: The start of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
    """
    __args__ = dict()
    __args__['applicationId'] = application_id
    __args__['filters'] = filters
    __args__['fleetId'] = fleet_id
    __args__['installationPath'] = installation_path
    __args__['jreDistribution'] = jre_distribution
    __args__['jreSecurityStatus'] = jre_security_status
    __args__['jreVendor'] = jre_vendor
    __args__['jreVersion'] = jre_version
    __args__['managedInstanceId'] = managed_instance_id
    __args__['osFamilies'] = os_families
    __args__['pathContains'] = path_contains
    __args__['timeEnd'] = time_end
    __args__['timeStart'] = time_start
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Jms/getInstallationSites:getInstallationSites', __args__, opts=opts, typ=GetInstallationSitesResult).value

    return AwaitableGetInstallationSitesResult(
        application_id=__ret__.application_id,
        filters=__ret__.filters,
        fleet_id=__ret__.fleet_id,
        id=__ret__.id,
        installation_path=__ret__.installation_path,
        installation_site_collections=__ret__.installation_site_collections,
        jre_distribution=__ret__.jre_distribution,
        jre_security_status=__ret__.jre_security_status,
        jre_vendor=__ret__.jre_vendor,
        jre_version=__ret__.jre_version,
        managed_instance_id=__ret__.managed_instance_id,
        os_families=__ret__.os_families,
        path_contains=__ret__.path_contains,
        time_end=__ret__.time_end,
        time_start=__ret__.time_start)


@_utilities.lift_output_func(get_installation_sites)
def get_installation_sites_output(application_id: Optional[pulumi.Input[Optional[str]]] = None,
                                  filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetInstallationSitesFilterArgs']]]]] = None,
                                  fleet_id: Optional[pulumi.Input[str]] = None,
                                  installation_path: Optional[pulumi.Input[Optional[str]]] = None,
                                  jre_distribution: Optional[pulumi.Input[Optional[str]]] = None,
                                  jre_security_status: Optional[pulumi.Input[Optional[str]]] = None,
                                  jre_vendor: Optional[pulumi.Input[Optional[str]]] = None,
                                  jre_version: Optional[pulumi.Input[Optional[str]]] = None,
                                  managed_instance_id: Optional[pulumi.Input[Optional[str]]] = None,
                                  os_families: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                  path_contains: Optional[pulumi.Input[Optional[str]]] = None,
                                  time_end: Optional[pulumi.Input[Optional[str]]] = None,
                                  time_start: Optional[pulumi.Input[Optional[str]]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetInstallationSitesResult]:
    """
    This data source provides the list of Fleet Installation Sites in Oracle Cloud Infrastructure Jms service.

    List Java installation sites in a Fleet filtered by query parameters.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_fleet_installation_sites = oci.Jms.get_installation_sites(fleet_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        application_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        installation_path=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        jre_distribution=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        jre_security_status=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        jre_vendor=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        jre_version=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        managed_instance_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        os_families=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        path_contains=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_end=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        time_start=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str application_id: The Fleet-unique identifier of the related application.
    :param str fleet_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the Fleet.
    :param str installation_path: The file system path of the installation.
    :param str jre_distribution: The distribution of the related Java Runtime.
    :param str jre_security_status: The security status of the Java Runtime.
    :param str jre_vendor: The vendor of the related Java Runtime.
    :param str jre_version: The version of the related Java Runtime.
    :param str managed_instance_id: The Fleet-unique identifier of the related managed instance.
    :param Sequence[str] os_families: The operating system type.
    :param str path_contains: Filter the list with path contains the given value.
    :param str time_end: The end of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
    :param str time_start: The start of the time period during which resources are searched (formatted according to [RFC3339](https://datatracker.ietf.org/doc/html/rfc3339)).
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetBackendsResult',
    'AwaitableGetBackendsResult',
    'get_backends',
    'get_backends_output',
]

@pulumi.output_type
class GetBackendsResult:
    """
    A collection of values returned by getBackends.
    """
    def __init__(__self__, backends=None, backendset_name=None, filters=None, id=None, load_balancer_id=None):
        if backends and not isinstance(backends, list):
            raise TypeError("Expected argument 'backends' to be a list")
        pulumi.set(__self__, "backends", backends)
        if backendset_name and not isinstance(backendset_name, str):
            raise TypeError("Expected argument 'backendset_name' to be a str")
        pulumi.set(__self__, "backendset_name", backendset_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if load_balancer_id and not isinstance(load_balancer_id, str):
            raise TypeError("Expected argument 'load_balancer_id' to be a str")
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)

    @property
    @pulumi.getter
    def backends(self) -> Sequence['outputs.GetBackendsBackendResult']:
        """
        The list of backends.
        """
        return pulumi.get(self, "backends")

    @property
    @pulumi.getter(name="backendsetName")
    def backendset_name(self) -> str:
        return pulumi.get(self, "backendset_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetBackendsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> str:
        return pulumi.get(self, "load_balancer_id")


class AwaitableGetBackendsResult(GetBackendsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetBackendsResult(
            backends=self.backends,
            backendset_name=self.backendset_name,
            filters=self.filters,
            id=self.id,
            load_balancer_id=self.load_balancer_id)


def get_backends(backendset_name: Optional[str] = None,
                 filters: Optional[Sequence[pulumi.InputType['GetBackendsFilterArgs']]] = None,
                 load_balancer_id: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetBackendsResult:
    """
    This data source provides the list of Backends in Oracle Cloud Infrastructure Load Balancer service.

    Lists the backend servers for a given load balancer and backend set.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_backends = oci.LoadBalancer.get_backends(backendset_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        load_balancer_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str backendset_name: The name of the backend set associated with the backend servers.  Example: `example_backend_set`
    :param str load_balancer_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the load balancer associated with the backend set and servers.
    """
    __args__ = dict()
    __args__['backendsetName'] = backendset_name
    __args__['filters'] = filters
    __args__['loadBalancerId'] = load_balancer_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:LoadBalancer/getBackends:getBackends', __args__, opts=opts, typ=GetBackendsResult).value

    return AwaitableGetBackendsResult(
        backends=__ret__.backends,
        backendset_name=__ret__.backendset_name,
        filters=__ret__.filters,
        id=__ret__.id,
        load_balancer_id=__ret__.load_balancer_id)


@_utilities.lift_output_func(get_backends)
def get_backends_output(backendset_name: Optional[pulumi.Input[str]] = None,
                        filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetBackendsFilterArgs']]]]] = None,
                        load_balancer_id: Optional[pulumi.Input[str]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetBackendsResult]:
    """
    This data source provides the list of Backends in Oracle Cloud Infrastructure Load Balancer service.

    Lists the backend servers for a given load balancer and backend set.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_backends = oci.LoadBalancer.get_backends(backendset_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        load_balancer_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str backendset_name: The name of the backend set associated with the backend servers.  Example: `example_backend_set`
    :param str load_balancer_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the load balancer associated with the backend set and servers.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetAppAccelerationPoliciesResult',
    'AwaitableGetAppAccelerationPoliciesResult',
    'get_app_acceleration_policies',
    'get_app_acceleration_policies_output',
]

@pulumi.output_type
class GetAppAccelerationPoliciesResult:
    """
    A collection of values returned by getAppAccelerationPolicies.
    """
    def __init__(__self__, compartment_id=None, display_name=None, filters=None, id=None, states=None, web_app_acceleration_policy_collections=None):
        if compartment_id and not isinstance(compartment_id, str):
            raise TypeError("Expected argument 'compartment_id' to be a str")
        pulumi.set(__self__, "compartment_id", compartment_id)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if states and not isinstance(states, list):
            raise TypeError("Expected argument 'states' to be a list")
        pulumi.set(__self__, "states", states)
        if web_app_acceleration_policy_collections and not isinstance(web_app_acceleration_policy_collections, list):
            raise TypeError("Expected argument 'web_app_acceleration_policy_collections' to be a list")
        pulumi.set(__self__, "web_app_acceleration_policy_collections", web_app_acceleration_policy_collections)

    @property
    @pulumi.getter(name="compartmentId")
    def compartment_id(self) -> str:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment.
        """
        return pulumi.get(self, "compartment_id")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        WebAppAccelerationPolicy display name, can be renamed.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetAppAccelerationPoliciesFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> Optional[str]:
        """
        The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the WebAppAccelerationPolicy.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def states(self) -> Optional[Sequence[str]]:
        """
        The current state of the WebAppAccelerationPolicy.
        """
        return pulumi.get(self, "states")

    @property
    @pulumi.getter(name="webAppAccelerationPolicyCollections")
    def web_app_acceleration_policy_collections(self) -> Sequence['outputs.GetAppAccelerationPoliciesWebAppAccelerationPolicyCollectionResult']:
        """
        The list of web_app_acceleration_policy_collection.
        """
        return pulumi.get(self, "web_app_acceleration_policy_collections")


class AwaitableGetAppAccelerationPoliciesResult(GetAppAccelerationPoliciesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetAppAccelerationPoliciesResult(
            compartment_id=self.compartment_id,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id,
            states=self.states,
            web_app_acceleration_policy_collections=self.web_app_acceleration_policy_collections)


def get_app_acceleration_policies(compartment_id: Optional[str] = None,
                                  display_name: Optional[str] = None,
                                  filters: Optional[Sequence[pulumi.InputType['GetAppAccelerationPoliciesFilterArgs']]] = None,
                                  id: Optional[str] = None,
                                  states: Optional[Sequence[str]] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetAppAccelerationPoliciesResult:
    """
    This data source provides the list of Web App Acceleration Policies in Oracle Cloud Infrastructure Waa service.

    Gets a list of all WebAppAccelerationPolicies in a compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_web_app_acceleration_policies = oci.Waa.get_app_acceleration_policies(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        states=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which to list resources.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str id: A filter to return only the WebAppAccelerationPolicy with the given [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param Sequence[str] states: A filter to return only resources that match the given lifecycleState.
    """
    __args__ = dict()
    __args__['compartmentId'] = compartment_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    __args__['id'] = id
    __args__['states'] = states
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Waa/getAppAccelerationPolicies:getAppAccelerationPolicies', __args__, opts=opts, typ=GetAppAccelerationPoliciesResult).value

    return AwaitableGetAppAccelerationPoliciesResult(
        compartment_id=__ret__.compartment_id,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id,
        states=__ret__.states,
        web_app_acceleration_policy_collections=__ret__.web_app_acceleration_policy_collections)


@_utilities.lift_output_func(get_app_acceleration_policies)
def get_app_acceleration_policies_output(compartment_id: Optional[pulumi.Input[str]] = None,
                                         display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                         filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetAppAccelerationPoliciesFilterArgs']]]]] = None,
                                         id: Optional[pulumi.Input[Optional[str]]] = None,
                                         states: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetAppAccelerationPoliciesResult]:
    """
    This data source provides the list of Web App Acceleration Policies in Oracle Cloud Infrastructure Waa service.

    Gets a list of all WebAppAccelerationPolicies in a compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_web_app_acceleration_policies = oci.Waa.get_app_acceleration_policies(compartment_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        states=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compartment_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compartment in which to list resources.
    :param str display_name: A filter to return only resources that match the entire display name given.
    :param str id: A filter to return only the WebAppAccelerationPolicy with the given [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm).
    :param Sequence[str] states: A filter to return only resources that match the given lifecycleState.
    """
    ...



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = [
    'GetComputeGlobalImageCapabilitySchemasVersionsResult',
    'AwaitableGetComputeGlobalImageCapabilitySchemasVersionsResult',
    'get_compute_global_image_capability_schemas_versions',
    'get_compute_global_image_capability_schemas_versions_output',
]

@pulumi.output_type
class GetComputeGlobalImageCapabilitySchemasVersionsResult:
    """
    A collection of values returned by getComputeGlobalImageCapabilitySchemasVersions.
    """
    def __init__(__self__, compute_global_image_capability_schema_id=None, compute_global_image_capability_schema_versions=None, display_name=None, filters=None, id=None):
        if compute_global_image_capability_schema_id and not isinstance(compute_global_image_capability_schema_id, str):
            raise TypeError("Expected argument 'compute_global_image_capability_schema_id' to be a str")
        pulumi.set(__self__, "compute_global_image_capability_schema_id", compute_global_image_capability_schema_id)
        if compute_global_image_capability_schema_versions and not isinstance(compute_global_image_capability_schema_versions, list):
            raise TypeError("Expected argument 'compute_global_image_capability_schema_versions' to be a list")
        pulumi.set(__self__, "compute_global_image_capability_schema_versions", compute_global_image_capability_schema_versions)
        if display_name and not isinstance(display_name, str):
            raise TypeError("Expected argument 'display_name' to be a str")
        pulumi.set(__self__, "display_name", display_name)
        if filters and not isinstance(filters, list):
            raise TypeError("Expected argument 'filters' to be a list")
        pulumi.set(__self__, "filters", filters)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)

    @property
    @pulumi.getter(name="computeGlobalImageCapabilitySchemaId")
    def compute_global_image_capability_schema_id(self) -> str:
        """
        The ocid of the compute global image capability schema
        """
        return pulumi.get(self, "compute_global_image_capability_schema_id")

    @property
    @pulumi.getter(name="computeGlobalImageCapabilitySchemaVersions")
    def compute_global_image_capability_schema_versions(self) -> Sequence['outputs.GetComputeGlobalImageCapabilitySchemasVersionsComputeGlobalImageCapabilitySchemaVersionResult']:
        """
        The list of compute_global_image_capability_schema_versions.
        """
        return pulumi.get(self, "compute_global_image_capability_schema_versions")

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> Optional[str]:
        """
        A user-friendly name. Does not have to be unique, and it's changeable. Avoid entering confidential information.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def filters(self) -> Optional[Sequence['outputs.GetComputeGlobalImageCapabilitySchemasVersionsFilterResult']]:
        return pulumi.get(self, "filters")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")


class AwaitableGetComputeGlobalImageCapabilitySchemasVersionsResult(GetComputeGlobalImageCapabilitySchemasVersionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetComputeGlobalImageCapabilitySchemasVersionsResult(
            compute_global_image_capability_schema_id=self.compute_global_image_capability_schema_id,
            compute_global_image_capability_schema_versions=self.compute_global_image_capability_schema_versions,
            display_name=self.display_name,
            filters=self.filters,
            id=self.id)


def get_compute_global_image_capability_schemas_versions(compute_global_image_capability_schema_id: Optional[str] = None,
                                                         display_name: Optional[str] = None,
                                                         filters: Optional[Sequence[pulumi.InputType['GetComputeGlobalImageCapabilitySchemasVersionsFilterArgs']]] = None,
                                                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetComputeGlobalImageCapabilitySchemasVersionsResult:
    """
    This data source provides the list of Compute Global Image Capability Schemas Versions in Oracle Cloud Infrastructure Core service.

    Lists Compute Global Image Capability Schema versions in the specified compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_compute_global_image_capability_schemas_versions = oci.Core.get_compute_global_image_capability_schemas_versions(compute_global_image_capability_schema_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compute_global_image_capability_schema_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compute global image capability schema
    :param str display_name: A filter to return only resources that match the given display name exactly.
    """
    __args__ = dict()
    __args__['computeGlobalImageCapabilitySchemaId'] = compute_global_image_capability_schema_id
    __args__['displayName'] = display_name
    __args__['filters'] = filters
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('oci:Core/getComputeGlobalImageCapabilitySchemasVersions:getComputeGlobalImageCapabilitySchemasVersions', __args__, opts=opts, typ=GetComputeGlobalImageCapabilitySchemasVersionsResult).value

    return AwaitableGetComputeGlobalImageCapabilitySchemasVersionsResult(
        compute_global_image_capability_schema_id=__ret__.compute_global_image_capability_schema_id,
        compute_global_image_capability_schema_versions=__ret__.compute_global_image_capability_schema_versions,
        display_name=__ret__.display_name,
        filters=__ret__.filters,
        id=__ret__.id)


@_utilities.lift_output_func(get_compute_global_image_capability_schemas_versions)
def get_compute_global_image_capability_schemas_versions_output(compute_global_image_capability_schema_id: Optional[pulumi.Input[str]] = None,
                                                                display_name: Optional[pulumi.Input[Optional[str]]] = None,
                                                                filters: Optional[pulumi.Input[Optional[Sequence[pulumi.InputType['GetComputeGlobalImageCapabilitySchemasVersionsFilterArgs']]]]] = None,
                                                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetComputeGlobalImageCapabilitySchemasVersionsResult]:
    """
    This data source provides the list of Compute Global Image Capability Schemas Versions in Oracle Cloud Infrastructure Core service.

    Lists Compute Global Image Capability Schema versions in the specified compartment.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_oci as oci

    test_compute_global_image_capability_schemas_versions = oci.Core.get_compute_global_image_capability_schemas_versions(compute_global_image_capability_schema_id=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference),
        display_name=%!v(PANIC=Format method: runtime error: invalid memory address or nil pointer dereference))
    ```


    :param str compute_global_image_capability_schema_id: The [OCID](https://docs.cloud.oracle.com/iaas/Content/General/Concepts/identifiers.htm) of the compute global image capability schema
    :param str display_name: A filter to return only resources that match the given display name exactly.
    """
    ...
